API docs for “spamfighter.plugin”

# Module s.plugin

Part of spamfighter View Source

Подсистема плагинов СпамоБорца и интерфейсы плагинов.

Class | INamedPlugin | Базовый интерфейс плагинов: плагин, который имеет имя.
Class | IDefaultDomainProvider | Интерфейс плагина, возвращающего ссылку на провайдер домена по умолчанию.
Class | IPartnerAuthorizerProvider | Интерфейс плагина, возвращающего ссылку на механизм авторизации партнеров.
Class | PluginNotFoundError | Не найден плагин с указанным именем.
Class | PluginAmbiguityError | Найдено более одного плагина с указанным именем.
Function | loadPlugin | Загрузить указанный плагин СпамоБорца. Возвращает

def loadPlugin(interface, name, package=None): (source)
Загрузить указанный плагин СпамоБорца. Возвращает экземлпяр объекта плагина.

Parameters | interface | интерфейс, который должен реализовывать плагин
| name | имя плагина (см. `INamedPlugin`) (type: `str` )